@@ -2,17 +2,23 @@
 # License:: Ruby's license (see the LICENSE file) or GNU GPL, at your option.
 # Website::http://home.gna.org/xmpp4r/
 
-require 'xmpp4r/xmlstanza'
+require 'xmpp4r/xmppstanza'
 require 'xmpp4r/jid'
 require 'digest/sha1'
 
+require 'xmpp4r/query'
+require 'xmpp4r/vcard/iq/vcard'
+
 module Jabber
   ##
   # IQ: Information/Query
   # (see RFC3920 - 9.2.3
   #
   # A class used to build/parse IQ requests/responses
-  class Iq < XMLStanza
+  class Iq < XMPPStanza
+    name_xmlns 'iq', 'jabber:client'
+    force_xmlns true
+
     @@element_classes = {}
 
     ##
@@ -20,13 +26,14 @@ module Jabber
     # type:: [Symbol] or nil, see Iq#type
     # to:: [JID] Recipient
     def initialize(type = nil, to = nil)
-      super("iq")
+      super()
+
       if not to.nil?
         set_to(to)
-      end 
+      end
       if not type.nil?
         set_type(type)
-      end 
+      end
     end
 
     ##
@@ -88,7 +95,7 @@ module Jabber
     ##
     # Returns the iq's query's namespace, or nil
     # result:: [String]
-    def queryns 
+    def queryns
       e = first_element('query')
       if e
         return e.namespace
@@ -100,30 +107,22 @@ module Jabber
     ##
     # Returns the iq's <vCard/> child, or nil
     # result:: [IqVcard]
-    def vcard 
+    def vcard
       first_element('vCard')
     end
 
     ##
-    # Create a new iq from a stanza,
-    # copies all attributes and children from xmlstanza
-    # xmlstanza:: [REXML::Element] Source stanza
-    # return:: [Iq] New stanza
-    def Iq.import(xmlstanza)
-      Iq::new.import(xmlstanza)
+    # Returns the iq's <pubsub/> child, or nil
+    # result:: [IqVcard]
+    def pubsub
+      first_element('pubsub')
     end
 
     ##
-    # Add an element to the Iq stanza
-    # element:: [REXML::Element] Element to add.
-    # Will be automatically converted (imported) to
-    # a class registered with add_elementclass
-    def typed_add(element)
-      if element.kind_of?(REXML::Element) && @@element_classes.has_key?(element.name)
-        super(@@element_classes[element.name]::import(element))
-      else
-        super(element)
-      end
+    # Returns the iq's <command/> child, or nil
+    # resulte:: [IqCommand]
+    def command
+      first_element("command")
     end
 
     ##
@@ -156,7 +155,7 @@ module Jabber
       query = IqQuery::new
       query.add_namespace('jabber:iq:auth')
       query.add(REXML::Element::new('username').add_text(jid.node))
-      query.add(REXML::Element::new('digest').add_text(Digest::SHA1.new(session_id + password).hexdigest))
+      query.add(REXML::Element::new('digest').add_text(Digest::SHA1.hexdigest(session_id + password)))
       query.add(REXML::Element::new('resource').add_text(jid.resource)) if not jid.resource.nil?
       iq.add(query)
       iq
@@ -207,23 +206,5 @@ module Jabber
       iq.add(query)
       iq
     end
-
-    ##
-    # Add a class by name.
-    # Elements with this name will be automatically converted
-    # to the specific class.
-    # Used for <query/>, <vCard>, <pubsub> etc.
-    # name:: [String] Element name
-    # elementclass:: [Class] Target class
-    def Iq.add_elementclass(name, elementclass)
-      @@element_classes[name] = elementclass
-    end
   end
 end
-
-# Actually these should be included at the top,
-# but then they would be unable to call Iq.add_elementclass
-# because it hasn't just been defined.
-
-require 'xmpp4r/query'
-require 'xmpp4r/vcard/iq/vcard'
